package com.io.yutian.auchestshop.util;

import com.io.yutian.aulib.nbt.NBTCompound;
import com.io.yutian.aulib.nbt.NBTItem;
import com.io.yutian.aulib.util.LangUtil;
import org.bukkit.Material;
import org.bukkit.inventory.Inventory;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class ItemStackUtil {

    public static boolean matches(@Nullable ItemStack original, @Nullable ItemStack tester) {
        if (original == null || tester == null) {
            return false;
        }
        original = original.clone();
        original.setAmount(1);
        tester = tester.clone();
        tester.setAmount(1);
        if (!original.isSimilar(tester)) {
            return false;
        }
        NBTItem nbtOriginal = new NBTItem(original);
        NBTItem nbtTester = new NBTItem(tester);
        NBTCompound nbtCompound0 = nbtOriginal.getTag();
        NBTCompound nbtCompound1 = nbtTester.getTag();
        return nbtCompound0.equals(nbtCompound1);
    }

    public static int countItems(Inventory inventory, @NotNull ItemStack item) {
        if (inventory == null) {
            return 0;
        }
        int count = 0;
        for (ItemStack itemStack : inventory) {
            if (itemStack == null || itemStack.getType() == Material.AIR) {
                continue;
            }
            if (matches(item, itemStack)) {
                count+= itemStack.getAmount();
            }
        }
        return count;
    }

    public static int countSpace(Inventory inventory, @NotNull ItemStack item) {
        if (inventory == null) {
            return 0;
        }
        int count = 0;
        int itemMaxStackSize = item.getMaxStackSize();
        for (ItemStack itemStack : inventory) {
            if (itemStack == null || itemStack.getType() == Material.AIR) {
                count+=itemMaxStackSize;
            } else if (matches(item, itemStack)) {
                count+=itemStack.getAmount() >= itemMaxStackSize ? 0 : itemMaxStackSize - itemStack.getAmount();
            }
        }
        return count;
    }

    public static String getItemName(ItemStack itemStack) {
        ItemMeta meta = itemStack.getItemMeta();
        if (meta != null && meta.hasDisplayName()) {
            return meta.getDisplayName();
        }
        Material material = itemStack.getType();
        String id = material.name().toLowerCase();
        boolean isBlock = material.isBlock();
        String prefix = isBlock ? "block" : "item";
        return LangUtil.getLang(prefix+".minecraft."+id);
    }

}
